**Example 1: 添加信任**

将恶意请求记录添加信任

Input: 

```
tccli cwp TrustMaliciousRequest --cli-unfold-argument  \
    --Id 1
```

Output: 
```
{
    "Response": {
        "RequestId": "354f4ac3-8546-4516-8c8a-69e3ab73aa8a"
    }
}
```

